@@ -4,9 +4,9 @@ import argparse
 import yaml
 import os
 import sys
-from jinja2 import Template
-from jinja2 import exceptions
+from jinja2 import Template, exceptions, StrictUndefined
 import kubetpl.aws as aws
+import kubetpl.gcp as gcp
 import tempfile
 
 kubectl_cmd_tpl = "{1} {2} --context {3} -f {0}"
@@ -80,8 +80,9 @@ def template_resources(resources_list, context, values):
     for resource in resources_list:
         with open(resource) as template_file:
             try:
-                template = Template(template_file.read())
-                templated_resource = template.render(values, aws=aws)
+                template = Template(template_file.read(),
+                                    undefined=StrictUndefined)
+                templated_resource = template.render(values, aws=aws, gcp=gcp)
                 if args.command == 'template':
                     print('### File: {0}'.format(resource))
                     print(templated_resource)
@@ -97,8 +98,9 @@ def template_resources(resources_list, context, values):
                         if res != 0:
                             print('kubectl error on file {0}'.format(resource))
                             exit(1)
-            except exceptions.TemplateSyntaxError as exc:
-                print("Error templating resource {0}, {1}".format(resource,
+            except (exceptions.TemplateSyntaxError,
+                    exceptions.UndefinedError) as exc:
+                print("Error templating resource {0}: {1}".format(resource,
                                                                   exc.message))
                 exit(1)
 
@@ -118,7 +120,7 @@ def main():
     for var_name in tpl_vars:
         try:
             template = Template(str(tpl_vars[var_name]))
-            tpl_vars[var_name] = template.render(tpl_vars, aws=aws)
+            tpl_vars[var_name] = template.render(tpl_vars, aws=aws, gcp=gcp)
         except Exception as exc:
             print('Error templating '
                   'variable "{0}": {1}'.format(var_name, ' '.join(exc.args)))
@@ -155,7 +157,12 @@ def main():
             (var_key, var_value) = var.split('=')
             tpl_vars[var_key] = var_value
 
-    template_resources(resources_to_template, resource_set['context'], tpl_vars)
+    if len(resources_to_template) > 0:
+        template_resources(resources_to_template, resource_set['context'], tpl_vars)
+    else:
+        print('No resources to template has been found, '
+              'please check including/excluding settings or '
+              'resources list in cluster config ')
 
 
 if __name__ == '__main__':
